@@ -118,9 +118,9 @@ sub extract_entries {
   my $smaps = [];
   # Maps are applied in order USER->STYLE->DRIVER
   if (defined(Biber::Config->getoption('sourcemap'))) {
-    # User maps
-    if (my $m = first {$_->{datatype} eq 'bibtex' and $_->{level} eq 'user' } Biber::Config->getoption('sourcemap')->@* ) {
-      push $smaps->@*, $m;
+    # User maps, allow multiple \DeclareSourcemap
+    if (my @m = grep {$_->{datatype} eq 'bibtex' and $_->{level} eq 'user' } Biber::Config->getoption('sourcemap')->@* ) {
+      push $smaps->@*, @m;
     }
     # Style maps
     # Allow multiple style maps from multiple \DeclareStyleSourcemap
@@ -505,7 +505,12 @@ sub create_entry {
               }
               $rkeys->@* = grep {$newkey ne $_} $rkeys->@*;
 
-              # Need to add the clone key to the section if allkeys is set since all keys
+              # Add to the section if explicitly nocited in the map
+              if ($step->{map_entry_nocite}) {
+                $section->add_citekeys($newkey);
+              }
+
+              # Need to add the new key to the section if allkeys is set since all keys
               # are cleared for allkeys sections initially
               if ($section->is_allkeys) {
                 $section->add_citekeys($newkey);
@@ -530,6 +535,11 @@ sub create_entry {
               }
               $rkeys->@* = grep {$clonekey ne $_} $rkeys->@*;
 
+              # Add to the section if explicitly nocited in the map
+              if ($step->{map_entry_nocite}) {
+                $section->add_citekeys($clonekey);
+              }
+
               # Need to add the clone key to the section if allkeys is set since all keys
               # are cleared for allkeys sections initially
               if ($section->is_allkeys) {
@@ -1836,7 +1846,7 @@ L<https://github.com/plk/biber/issues>.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2017 François Charette and Philip Kime, all rights reserved.
+Copyright 2009-2018 François Charette and Philip Kime, all rights reserved.
 
 This module is free software.  You can redistribute it and/or
 modify it under the terms of the Artistic License 2.0.
